loadable_buttons library
Classes
- AsyncElevatedButton
- AsyncElevatedButton is a custom widget that allows to load a child.
- AsyncFilledButton
- AsyncFilledButton is a custom widget that allows to load a child.
- AsyncFloatingActionButton
- AsyncFloatingActionButton is a custom widget that allows to load a child.
- AsyncIconButton
- AsyncIconButton is a custom widget that allows to load a child.
- AsyncOutlinedButton
- AsyncOutlinedButton is a custom widget that allows to load a child.
- AsyncTextButton
- AsyncTextButton is a custom widget that allows to load a child.
Enums
- TransitionAnimationType
- Enum to define the type of loading animation.